@@ -214,7 +214,7 @@ class DescribeCallDetailRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -313,7 +313,7 @@ class DescribeDetailEventRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位s）。通过 DescribeRoomInformation（查询房间列表）接口获取。（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -592,6 +592,57 @@ class DescribeRealtimeScaleResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeRecordStatisticRequest(AbstractModel):
+    """DescribeRecordStatistic请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 查询开始日期。
+        :type StartTime: str
+        :param EndTime: 查询结束日期。
+        :type EndTime: str
+        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回多个应用的合计值。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class DescribeRecordStatisticResponse(AbstractModel):
+    """DescribeRecordStatistic返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppIdUsages: 应用的用量信息数组。
+        :type SdkAppIdUsages: list of SdkAppIdRecordUsage
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.SdkAppIdUsages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("SdkAppIdUsages") is not None:
+            self.SdkAppIdUsages = []
+            for item in params.get("SdkAppIdUsages"):
+                obj = SdkAppIdRecordUsage()
+                obj._deserialize(item)
+                self.SdkAppIdUsages.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeRoomInformationRequest(AbstractModel):
     """DescribeRoomInformation请求参数结构体
 
@@ -601,7 +652,7 @@ class DescribeRoomInformationRequest(AbstractModel):
         """
         :param SdkAppId: 用户sdkappid
         :type SdkAppId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -659,6 +710,110 @@ class DescribeRoomInformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeTrtcInteractiveTimeRequest(AbstractModel):
+    """DescribeTrtcInteractiveTime请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 查询开始时间，格式为YYYY-MM-DD。
+        :type StartTime: str
+        :param EndTime: 查询结束时间，格式为YYYY-MM-DD。
+单次查询统计区间最多不能超过31天。
+        :type EndTime: str
+        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回所有应用的合计值。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class DescribeTrtcInteractiveTimeResponse(AbstractModel):
+    """DescribeTrtcInteractiveTime返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Usages: 应用的用量信息数组。
+        :type Usages: list of OneSdkAppIdUsagesInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Usages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Usages") is not None:
+            self.Usages = []
+            for item in params.get("Usages"):
+                obj = OneSdkAppIdUsagesInfo()
+                obj._deserialize(item)
+                self.Usages.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeTrtcMcuTranscodeTimeRequest(AbstractModel):
+    """DescribeTrtcMcuTranscodeTime请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 查询开始时间，格式为YYYY-MM-DD。
+        :type StartTime: str
+        :param EndTime: 查询结束时间，格式为YYYY-MM-DD。
+单次查询统计区间最多不能超过31天。
+        :type EndTime: str
+        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回多个应用的合计值。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class DescribeTrtcMcuTranscodeTimeResponse(AbstractModel):
+    """DescribeTrtcMcuTranscodeTime返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Usages: 应用的用量信息数组。
+        :type Usages: list of OneSdkAppIdTranscodeTimeUsagesInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Usages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Usages") is not None:
+            self.Usages = []
+            for item in params.get("Usages"):
+                obj = OneSdkAppIdTranscodeTimeUsagesInfo()
+                obj._deserialize(item)
+                self.Usages.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeUserInformationRequest(AbstractModel):
     """DescribeUserInformation请求参数结构体
 
@@ -668,7 +823,7 @@ class DescribeUserInformationRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -731,6 +886,44 @@ class DescribeUserInformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DismissRoomByStrRoomIdRequest(AbstractModel):
+    """DismissRoomByStrRoomId请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: TRTC的SDKAppId。
+        :type SdkAppId: int
+        :param RoomId: 房间号。
+        :type RoomId: str
+        """
+        self.SdkAppId = None
+        self.RoomId = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.RoomId = params.get("RoomId")
+
+
+class DismissRoomByStrRoomIdResponse(AbstractModel):
+    """DismissRoomByStrRoomId返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DismissRoomRequest(AbstractModel):
     """DismissRoom请求参数结构体
 
@@ -892,7 +1085,7 @@ class LayoutParams(AbstractModel):
 
     def __init__(self):
         """
-        :param Template: 混流布局模板ID，0为悬浮模板(默认);1为九宫格模板;2为屏幕分享模板;3为画中画模板。
+        :param Template: 混流布局模板ID，0为悬浮模板(默认);1为九宫格模板;2为屏幕分享模板;3为画中画模板;4为自定义模板。
         :type Template: int
         :param MainVideoUserId: 屏幕分享模板、悬浮模板、画中画模板中有效，代表大画面对应的用户ID。
         :type MainVideoUserId: str
@@ -904,6 +1097,8 @@ class LayoutParams(AbstractModel):
         :type MainVideoRightAlign: int
         :param MixVideoUids: 悬浮模板、九宫格、屏幕分享模板有效。设置此参数后，输出流混合此参数中包含用户的音视频，以及其他用户的纯音频。最多可设置16个用户。
         :type MixVideoUids: list of str
+        :param PresetLayoutConfig: 自定义模板中有效，指定用户视频在混合画面中的位置。
+        :type PresetLayoutConfig: list of PresetLayoutConfig
         """
         self.Template = None
         self.MainVideoUserId = None
@@ -911,6 +1106,7 @@ class LayoutParams(AbstractModel):
         self.SmallVideoLayoutParams = None
         self.MainVideoRightAlign = None
         self.MixVideoUids = None
+        self.PresetLayoutConfig = None
 
 
     def _deserialize(self, params):
@@ -922,6 +1118,72 @@ class LayoutParams(AbstractModel):
             self.SmallVideoLayoutParams._deserialize(params.get("SmallVideoLayoutParams"))
         self.MainVideoRightAlign = params.get("MainVideoRightAlign")
         self.MixVideoUids = params.get("MixVideoUids")
+        if params.get("PresetLayoutConfig") is not None:
+            self.PresetLayoutConfig = []
+            for item in params.get("PresetLayoutConfig"):
+                obj = PresetLayoutConfig()
+                obj._deserialize(item)
+                self.PresetLayoutConfig.append(obj)
+
+
+class OneSdkAppIdTranscodeTimeUsagesInfo(AbstractModel):
+    """旁路转码时长的查询结果
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppIdTranscodeTimeUsages: 旁路转码时长查询结果数组
+        :type SdkAppIdTranscodeTimeUsages: list of SdkAppIdTrtcMcuTranscodeTimeUsage
+        :param TotalNum: 查询记录数量
+        :type TotalNum: int
+        :param SdkAppId: 所查询的应用ID，可能值为:1-应用的应用ID，2-total，显示为total则表示查询的是所有应用的用量合计值。
+        :type SdkAppId: str
+        """
+        self.SdkAppIdTranscodeTimeUsages = None
+        self.TotalNum = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        if params.get("SdkAppIdTranscodeTimeUsages") is not None:
+            self.SdkAppIdTranscodeTimeUsages = []
+            for item in params.get("SdkAppIdTranscodeTimeUsages"):
+                obj = SdkAppIdTrtcMcuTranscodeTimeUsage()
+                obj._deserialize(item)
+                self.SdkAppIdTranscodeTimeUsages.append(obj)
+        self.TotalNum = params.get("TotalNum")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class OneSdkAppIdUsagesInfo(AbstractModel):
+    """单个SdkAppId的音视频互动计费时长用量数组和数组长度。
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalNum: 该 SdkAppId 对应的用量记录数长度
+        :type TotalNum: int
+        :param SdkAppIdTrtcTimeUsages: 用量数组
+        :type SdkAppIdTrtcTimeUsages: list of SdkAppIdTrtcUsage
+        :param SdkAppId: 应用ID
+        :type SdkAppId: str
+        """
+        self.TotalNum = None
+        self.SdkAppIdTrtcTimeUsages = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.TotalNum = params.get("TotalNum")
+        if params.get("SdkAppIdTrtcTimeUsages") is not None:
+            self.SdkAppIdTrtcTimeUsages = []
+            for item in params.get("SdkAppIdTrtcTimeUsages"):
+                obj = SdkAppIdTrtcUsage()
+                obj._deserialize(item)
+                self.SdkAppIdTrtcTimeUsages.append(obj)
+        self.SdkAppId = params.get("SdkAppId")
 
 
 class OutputParams(AbstractModel):
@@ -953,6 +1215,51 @@ class OutputParams(AbstractModel):
         self.RecordAudioOnly = params.get("RecordAudioOnly")
 
 
+class PresetLayoutConfig(AbstractModel):
+    """自定义模板中有效，指定用户视频在混合画面中的位置。
+
+    """
+
+    def __init__(self):
+        """
+        :param UserId: 指定显示在该画面上的用户ID。如果不指定用户ID，会按照用户加入房间的顺序自动匹配PresetLayoutConfig中的画面设置。
+        :type UserId: str
+        :param StreamType: 当该画面指定用户时，代表用户的流类型。0为摄像头，1为屏幕分享。小画面为web用户时此值填0。
+        :type StreamType: int
+        :param ImageWidth: 该画面在输出时的宽度，单位为像素值，不填默认为0。
+        :type ImageWidth: int
+        :param ImageHeight: 该画面在输出时的高度，单位为像素值，不填默认为0。
+        :type ImageHeight: int
+        :param LocationX: 该画面在输出时的X偏移，单位为像素值，LocationX与ImageWidth之和不能超过混流输出的总宽度，不填默认为0。
+        :type LocationX: int
+        :param LocationY: 该画面在输出时的Y偏移，单位为像素值，LocationY与ImageHeight之和不能超过混流输出的总高度，不填默认为0。
+        :type LocationY: int
+        :param ZOrder: 该画面在输出时的层级，单位为像素值，不填默认为0。
+        :type ZOrder: int
+        :param RenderMode: 该画面在输出时的显示模式：0为裁剪，1为缩放，不填默认为0。
+        :type RenderMode: int
+        """
+        self.UserId = None
+        self.StreamType = None
+        self.ImageWidth = None
+        self.ImageHeight = None
+        self.LocationX = None
+        self.LocationY = None
+        self.ZOrder = None
+        self.RenderMode = None
+
+
+    def _deserialize(self, params):
+        self.UserId = params.get("UserId")
+        self.StreamType = params.get("StreamType")
+        self.ImageWidth = params.get("ImageWidth")
+        self.ImageHeight = params.get("ImageHeight")
+        self.LocationX = params.get("LocationX")
+        self.LocationY = params.get("LocationY")
+        self.ZOrder = params.get("ZOrder")
+        self.RenderMode = params.get("RenderMode")
+
+
 class QualityData(AbstractModel):
     """Es返回的质量数据
 
@@ -1015,6 +1322,81 @@ class RealtimeData(AbstractModel):
         self.DataType = params.get("DataType")
 
 
+class RecordUsage(AbstractModel):
+    """录制的使用信息。
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeKey: 本组数据对应的时间点，格式如:2020-09-07或2020-09-07 00:05:05。
+        :type TimeKey: str
+        :param Class1VideoTime: 视频时长-标清SD，单位：秒。
+        :type Class1VideoTime: int
+        :param Class2VideoTime: 视频时长-高清HD，单位：秒。
+        :type Class2VideoTime: int
+        :param Class3VideoTime: 视频时长-超清HD，单位：秒。
+        :type Class3VideoTime: int
+        :param AudioTime: 语音时长，单位：秒。
+        :type AudioTime: int
+        """
+        self.TimeKey = None
+        self.Class1VideoTime = None
+        self.Class2VideoTime = None
+        self.Class3VideoTime = None
+        self.AudioTime = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.Class1VideoTime = params.get("Class1VideoTime")
+        self.Class2VideoTime = params.get("Class2VideoTime")
+        self.Class3VideoTime = params.get("Class3VideoTime")
+        self.AudioTime = params.get("AudioTime")
+
+
+class RemoveUserByStrRoomIdRequest(AbstractModel):
+    """RemoveUserByStrRoomId请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: TRTC的SDKAppId。
+        :type SdkAppId: int
+        :param RoomId: 房间号。
+        :type RoomId: str
+        :param UserIds: 要移出的用户列表，最多10个。
+        :type UserIds: list of str
+        """
+        self.SdkAppId = None
+        self.RoomId = None
+        self.UserIds = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.RoomId = params.get("RoomId")
+        self.UserIds = params.get("UserIds")
+
+
+class RemoveUserByStrRoomIdResponse(AbstractModel):
+    """RemoveUserByStrRoomId返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class RemoveUserRequest(AbstractModel):
     """RemoveUser请求参数结构体
 
@@ -1126,6 +1508,105 @@ class ScaleInfomation(AbstractModel):
         self.RoomNumbers = params.get("RoomNumbers")
 
 
+class SdkAppIdRecordUsage(AbstractModel):
+    """SdkAppId级别录制时长数据。
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: SdkAppId的值。
+        :type SdkAppId: str
+        :param Usages: 统计的时间点数据。
+        :type Usages: list of RecordUsage
+        """
+        self.SdkAppId = None
+        self.Usages = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        if params.get("Usages") is not None:
+            self.Usages = []
+            for item in params.get("Usages"):
+                obj = RecordUsage()
+                obj._deserialize(item)
+                self.Usages.append(obj)
+
+
+class SdkAppIdTrtcMcuTranscodeTimeUsage(AbstractModel):
+    """查询旁路转码计费时长。
+    查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeKey: 本组数据对应的时间点，格式如：2020-09-07或2020-09-07 00:05:05。
+        :type TimeKey: str
+        :param AudioTime: 语音时长，单位：秒。
+        :type AudioTime: int
+        :param VideoTimeSd: 视频时长-标清SD，单位：秒。
+        :type VideoTimeSd: int
+        :param VideoTimeHd: 视频时长-高清HD，单位：秒。
+        :type VideoTimeHd: int
+        :param VideoTimeFhd: 视频时长-全高清FHD，单位：秒。
+        :type VideoTimeFhd: int
+        """
+        self.TimeKey = None
+        self.AudioTime = None
+        self.VideoTimeSd = None
+        self.VideoTimeHd = None
+        self.VideoTimeFhd = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.AudioTime = params.get("AudioTime")
+        self.VideoTimeSd = params.get("VideoTimeSd")
+        self.VideoTimeHd = params.get("VideoTimeHd")
+        self.VideoTimeFhd = params.get("VideoTimeFhd")
+
+
+class SdkAppIdTrtcUsage(AbstractModel):
+    """查询音视频互动时长的输出数据。
+    查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeKey: 本组数据对应的时间点，格式如：2020-09-07或2020-09-07 00:05:05。
+        :type TimeKey: str
+        :param AudioTime: 语音时长，单位：秒。
+        :type AudioTime: int
+        :param AudioVideoTime: 音视频时长，单位：秒。
+2019年10月11日前注册，没有变更为 [新计费模式](https://cloud.tencent.com/document/product/647/17157) 的用户才会返回此值。
+        :type AudioVideoTime: int
+        :param VideoTimeSd: 视频时长-标清SD，单位：秒。
+        :type VideoTimeSd: int
+        :param VideoTimeHd: 视频时长-高清HD，单位：秒。
+        :type VideoTimeHd: int
+        :param VideoTimeHdp: 视频时长-超清HD，单位：秒。
+        :type VideoTimeHdp: int
+        """
+        self.TimeKey = None
+        self.AudioTime = None
+        self.AudioVideoTime = None
+        self.VideoTimeSd = None
+        self.VideoTimeHd = None
+        self.VideoTimeHdp = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.AudioTime = params.get("AudioTime")
+        self.AudioVideoTime = params.get("AudioVideoTime")
+        self.VideoTimeSd = params.get("VideoTimeSd")
+        self.VideoTimeHd = params.get("VideoTimeHd")
+        self.VideoTimeHdp = params.get("VideoTimeHdp")
+
+
 class SmallVideoLayoutParams(AbstractModel):
     """画中画模板中有效，代表小画面的布局参数
 
